@@ -1,35 +1,70 @@
 #' Confidence Interval for Proportions
 #'
-#' This function computes a confidence interval for proportions for one or more variables, optionally
-#' by a grouping and/or split variable.
+#' This function computes a confidence interval for proportions for one or more
+#' variables, optionally by a grouping and/or split variable.
 #'
-#' The Wald confidence interval which is based on the normal approximation to the binomial distribution are
-#' computed by specifying \code{method = "wald"}, while the Wilson (1927) confidence interval (aka Wilson
-#' score interval) is requested by specifying \code{method = "wilson"}. By default, Wilson confidence
-#' interval is computed which have been shown to be reliable in small samples of n = 40 or less, and
-#' larger samples of n > 40 (Brown, Cai & DasGupta, 2001), while the Wald confidence intervals is
-#' inadequate in small samples and when \emph{p} is near 0 or 1 (Agresti & Coull, 1998).
+#' The Wald confidence interval which is based on the normal approximation to the
+#' binomial distribution are computed by specifying \code{method = "wald"}, while
+#' the Wilson (1927) confidence interval (aka Wilson score interval) is requested
+#' by specifying \code{method = "wilson"}. By default, Wilson confidence interval
+#' is computed which have been shown to be reliable in small samples of n = 40 or
+#' less, and larger samples of n > 40 (Brown, Cai & DasGupta, 2001), while the
+#' Wald confidence intervals is inadequate in small samples and when \emph{p} is
+#' near 0 or 1 (Agresti & Coull, 1998).
 #'
-#' @param x              a numeric vector, matrix or data frame with numeric variables with 0 and 1 values,
-#'                       i.e., factors and character variables are excluded from \code{x} before conducting
-#'                       the analysis.
-#' @param method         a character string specifying the method for computing the confidence interval,
-#'                       must be one of \code{"wald"}, or \code{"wilson"} (default).
-#' @param alternative    a character string specifying the alternative hypothesis, must be one of
-#'                       \code{"two.sided"} (default), \code{"greater"} or \code{"less"}.
-#' @param conf.level     a numeric value between 0 and 1 indicating the confidence level of the interval.
-#' @param group          a numeric vector, character vector or factor as grouping variable.
-#' @param split          a numeric vector, character vector or factor as split variable.
-#' @param sort.var       logical: if \code{TRUE}, output table is sorted by variables when specifying \code{group}.
-#' @param na.omit        logical: if \code{TRUE}, incomplete cases are removed before conducting the analysis
-#'                       (i.e., listwise deletion) when specifying more than one outcome variable.
-#' @param digits         an integer value indicating the number of decimal places to be used.
-#' @param as.na          a numeric vector indicating user-defined missing values,
-#'                       i.e. these values are converted to \code{NA} before conducting the analysis.
-#'                       Note that \code{as.na()} function is only applied to \code{x}, but
-#'                       not to \code{group} or \code{split}.
-#' @param check          logical: if \code{TRUE}, argument specification is checked.
-#' @param output         logical: if \code{TRUE}, output is shown on the console.
+#' @param ...         a numeric vector, matrix or data frame with numeric variables
+#'                    with 0 and 1 values, i.e., factors and character variables
+#'                    are excluded from \code{x} before conducting the analysis.
+#'                    Alternatively, an expression indicating the variable
+#'                    names in \code{data} e.g., \code{ci.prop(x1, x2, x3, data = dat)}.
+#'                    Note that the operators \code{.}, \code{+}, \code{-}, \code{~},
+#'                    \code{:}, \code{::}, and \code{!} can also be used to select
+#'                    variables, see 'Details' in the \code{\link{df.subset}}
+#'                    function.
+#' @param data        a data frame when specifying one or more variables in the
+#'                    argument \code{...}. Note that the argument is \code{NULL}
+#'                    when specifying a numeric vector, matrix or data frame for
+#'                    the argument \code{...}.
+#' @param method      a character string specifying the method for computing the
+#'                    confidence interval, must be one of \code{"wald"}, or
+#'                    \code{"wilson"} (default).
+#' @param alternative a character string specifying the alternative hypothesis,
+#'                    must be one of \code{"two.sided"} (default), \code{"greater"}
+#'                    or \code{"less"}.
+#' @param conf.level  a numeric value between 0 and 1 indicating the confidence
+#'                    level of the interval.
+#' @param group       either a character string indicating the variable name of
+#'                    the grouping variable in \code{...} or \code{data}, or a
+#'                    vector representing the grouping variable. Note that a
+#'                    grouping variable can only be used when computing confidence
+#'                    intervals with unknown population standard deviation and
+#'                    population variance.
+#' @param split       either a character string indicating the variable name of
+#'                    the split variable in \code{...} or \code{data}, or a vector
+#'                    representing the split variable. Note that a grouping
+#'                    variable can only be used when computing confidence intervals
+#'                    with unknown population standard deviation and population
+#'                    variance.
+#' @param sort.var    logical: if \code{TRUE}, output table is sorted by variables
+#'                    when specifying \code{group}.
+#' @param na.omit     logical: if \code{TRUE}, incomplete cases are removed before
+#'                    conducting the analysis (i.e., listwise deletion) when specifying
+#'                    more than one outcome variable.
+#' @param digits      an integer value indicating the number of decimal places to
+#'                    be used.
+#' @param as.na       a numeric vector indicating user-defined missing values,
+#'                    i.e. these values are converted to \code{NA} before conducting
+#'                    the analysis. Note that \code{as.na()} function is only applied
+#'                    to \code{x}, but not to \code{group} or \code{split}.
+#' @param write       a character string naming a text file with file extension
+#'                    \code{".txt"} (e.g., \code{"Output.txt"}) for writing the
+#'                    output into a text file.
+#' @param append      logical: if \code{TRUE} (default), output will be appended
+#'                    to an existing text file with extension \code{.txt} specified
+#'                    in \code{write}, if \code{FALSE} existing text file will be
+#'                    overwritten.
+#' @param check       logical: if \code{TRUE} (default), argument specification is checked.
+#' @param output      logical: if \code{TRUE} (default), output is shown on the console.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
@@ -40,17 +75,18 @@
 #' \code{\link{descript}}
 #'
 #' @references
-#' Agresti, A. & Coull, B.A. (1998). Approximate is better than "exact" for interval estimation of binomial
-#' proportions. \emph{American Statistician, 52}, 119-126.
+#' Agresti, A. & Coull, B.A. (1998). Approximate is better than "exact" for
+#' interval estimation of binomial proportions. \emph{American Statistician, 52},
+#' 119-126.
 #'
-#' Brown, L. D., Cai, T. T., & DasGupta, A., (2001). Interval estimation for a binomial proportion.
-#' \emph{Statistical Science, 16}, 101-133.
+#' Brown, L. D., Cai, T. T., & DasGupta, A., (2001). Interval estimation for a
+#' binomial proportion. \emph{Statistical Science, 16}, 101-133.
 #'
-#' Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). \emph{Statistics in psychology - Using R and SPSS}.
-#' John Wiley & Sons.
+#' Rasch, D., Kubinger, K. D., & Yanagida, T. (2011). \emph{Statistics in psychology
+#' - Using R and SPSS}. John Wiley & Sons.
 #'
-#' Wilson, E. B. (1927). Probable inference, the law of succession, and statistical inference.
-#' \emph{Journal of the American Statistical Association, 22}, 209-212.
+#' Wilson, E. B. (1927). Probable inference, the law of succession, and statistical
+#' inference. \emph{Journal of the American Statistical Association, 22}, 209-212.
 #'
 #' @return
 #' Returns an object of class \code{misty.object}, which is a list with following
@@ -58,116 +94,133 @@
 #' \tabular{ll}{
 #' \code{call} \tab function call \cr
 #' \code{type} \tab type of analysis \cr
-#' \code{data} \tab list with the input specified in \code{x}, \code{group}, and
-#'                  \code{split} \cr
-#' \code{args} \tab specification of function arguments  \cr
+#' \code{data} \tab list with the input specified in \code{...}, \code{data}, \code{group}, and \code{split} \cr
+#' \code{args} \tab specification of function arguments \cr
 #' \code{result} \tab result table \cr
 #' }
 #'
 #' @export
 #'
 #' @examples
-#' dat <- data.frame(group1 = c(1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2),
-#'                   group2 = c(1, 1, 1, 2, 2, 2, 1, 1, 1, 2, 2, 2),
-#'                   x1 = c(0, 1, 0, 0, 1, 1, 0, 1, NA, 0, 1, 0),
-#'                   x2 = c(0, NA, 1, 0, 1, 1, 0, 0, 1, 1, 1, 1),
-#'                   x3 = c(1, 1, 1, 0, 1, NA, 1, NA, 0, 0, 0, 1))
+#' # Example 1a: Two-Sided 95% CI for 'vs'
+#' ci.prop(mtcars$vs)
+#
+#' # Example 1b: Alternative specification using the 'data' argument
+#' ci.prop(vs, data = mtcars)
 #'
-#' # Two-Sided 95% CI for x1
-#' ci.prop(dat$x1)
+#' # Example 2: Two-Sided 95% CI using Wald method
+#' ci.prop(mtcars$vs, method = "wald")
 #'
-#' # Two-Sided 95% CI for x1 using Wald method
-#' ci.prop(dat$x1, method = "wald")
+#' # Example 3: One-Sided 95% CI
+#' ci.prop(mtcars$vs, alternative = "less")
 #'
-#' # One-Sided 95% CI for x1
-#' ci.prop(dat$x1, alternative = "less")
+#' # Example 4: Two-Sided 99% CI
+#' ci.prop(mtcars$vs, conf.level = 0.99)
 #'
-#' # Two-Sided 99% CI
-#' ci.prop(dat$x1, conf.level = 0.99)
+#' # Example 5: Two-Sided 95% CI, print results with 4 digits
+#' ci.prop(mtcars$vs, digits = 4)
 #'
-#' # Two-Sided 95% CI, print results with 4 digits
-#' ci.prop(dat$x1, digits = 4)
-#'
-#' # Two-Sided 95% CI for x1, x2, and x3,
+#' # Example 6a: Two-Sided 95% CI for 'vs' and 'am',
 #' # listwise deletion for missing data
-#' ci.prop(dat[, c("x1", "x2", "x3")], na.omit = TRUE)
+#' ci.prop(mtcars[, c("vs", "am")], na.omit = TRUE)
 #'
-#' # Two-Sided 95% CI for x1, x2, and x3,
-#' # analysis by group1 separately
-#' ci.prop(dat[, c("x1", "x2", "x3")], group = dat$group1)
+#' # Example 6b: Alternative specification using the 'data' argument
+#' # listwise deletion for missing data
+#' ci.prop(vs, am, data = mtcars, na.omit = TRUE)
 #'
-#' # Two-Sided 95% CI for x1, x2, and x3,
-#' # analysis by group1 separately, sort by variables
-#' ci.prop(dat[, c("x1", "x2", "x3")], group = dat$group1, sort.var = TRUE)
+#' # Example 7a: Two-Sided 95% CI, analysis by 'gear' separately
+#' ci.prop(mtcars[, c("vs", "am")], group = mtcars$gear)
 #'
-#' # Two-Sided 95% CI for x1, x2, and x3,
-#' # split analysis by group1
-#' ci.prop(dat[, c("x1", "x2", "x3")], split = dat$group1)
+#' # Example 7b: Alternative specification using the 'data' argument
+#' ci.prop(vs, am, data = mtcars, group = "gear")
 #'
-#' # Two-Sided 95% CI for x1, x2, and x3,
-#' # analysis by group1 separately, split analysis by group2
-#' ci.prop(dat[, c("x1", "x2", "x3")],
-#'         group = dat$group1, split = dat$group2)
-ci.prop <- function(x, method = c("wald", "wilson"), alternative = c("two.sided", "less", "greater"),
-                    conf.level = 0.95, group = NULL, split = NULL, sort.var = FALSE, na.omit = FALSE,
-                    digits = 3, as.na = NULL, check = TRUE, output = TRUE) {
+#' # Example 8: Two-Sided 95% CI, analysis by 'gear' separately, sort by variables
+#' ci.prop(mtcars[, c("vs", "am")], group = mtcars$gear, sort.var = TRUE)
+#'
+#' # Example 9: Two-Sided 95% CI, split analysis by 'cyl'
+#' ci.prop(mtcars[, c("vs", "am")], split = mtcars$cyl)
+#'
+#' # Example 10a: Two-Sided 95% CI, analysis by 'gear' separately, split by 'cyl'
+#' ci.prop(mtcars[, c("vs", "am")], group = mtcars$gear, split = mtcars$cyl)
+#'
+#' # Example 10b: Alternative specification using the 'data' argument
+#' ci.prop(vs, am, data = mtcars, group = "gear", split = "cyl")
+#'
+#' \dontrun{
+#' # Example 11: Write results into a text file
+#' ci.prop(vs, am, data = mtcars, group = "gear", split = "cyl", write = "Prop.txt")
+#' }
+ci.prop <- function(..., data = NULL, method = c("wald", "wilson"),
+                    alternative = c("two.sided", "less", "greater"),
+                    conf.level = 0.95, group = NULL, split = NULL, sort.var = FALSE,
+                    na.omit = FALSE, digits = 3, as.na = NULL, write = NULL, append = TRUE,
+                    check = TRUE, output = TRUE) {
 
   #_____________________________________________________________________________
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input 'x' is missing
-  if (isTRUE(missing(x))) { stop("Please specify a numeric vector, matrix or data frame with numeric variables for the argument 'x'.", call. = FALSE) }
+  # Check if input '...' is missing
+  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
 
-  # Check if input 'x' is NULL
-  if (isTRUE(is.null(x))) { stop("Input specified for the argument 'x' is NULL.", call. = FALSE) }
+  # Check if input '...' is NULL
+  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
 
-  # Check 'group'
-  if (isTRUE(!is.null(group))) {
+  # Check if input 'data' is data frame
+  if (isTRUE(!is.null(data) && !is.data.frame(data))) { stop("Please specify a data frame for the argument 'data'.", call. = FALSE) }
 
-    if (ncol(data.frame(group)) != 1L) { stop("More than one grouping variable specified for the argument 'group'.",call. = FALSE) }
+  #_____________________________________________________________________________
+  #
+  # Data -----------------------------------------------------------------------
 
-    if (nrow(data.frame(group)) != nrow(data.frame(x))) { stop("Length of the vector or factor specified in the argument 'group' does not match with 'x'.", call. = FALSE) }
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data using the argument 'data' ####
 
-    # Convert group into a vector
-    group <- unlist(group, use.names = FALSE)
+  if (isTRUE(!is.null(data))) {
 
-  }
+    # Variable names
+    var.names <- .var.names(..., data = data, group = group, split = split, check.chr = "a numeric vector, matrix or data frame")
 
-  # Check 'split'
-  if (isTRUE(!is.null(split))) {
+    # Extract variables
+    x <- data[, var.names]
 
-    if (ncol(data.frame(split)) != 1L) { stop("More than one split variable specified for the argument 'split'.",call. = FALSE) }
+    # Grouping variable
+    if (isTRUE(!is.null(group))) { group <- data[, group] }
 
-    if (nrow(data.frame(split)) != nrow(data.frame(x))) { stop("Length of the vector or factor specified in the argument 'split' does not match with 'x'.", call. = FALSE) }
+    # Split variable
+    if (isTRUE(!is.null(split))) { split <- data[, split] }
 
-    # Convert 'split' into a vector
-    split <- unlist(split, use.names = FALSE)
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data without using the argument 'data' ####
+
+  } else {
+
+    # Extract data
+    x <- eval(..., enclos = parent.frame())
+
+    # Data and cluster
+    var.group <- .var.group(data = x, group = group, split = split)
+
+    # Data
+    if (isTRUE(!is.null(var.group$data)))  { x <- var.group$data }
+
+    # Grouping variable
+    if (isTRUE(!is.null(var.group$group))) { group <- var.group$group }
+
+    # Split variable
+    if (isTRUE(!is.null(var.group$split))) { group <- var.group$split }
 
   }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-  ## As data frame ####
+  ## Data Frame ####
 
   x <- as.data.frame(x, stringsAsFactors = FALSE)
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Convert user-missing values into NA ####
 
-  if (isTRUE(!is.null(as.na))) {
-
-    # Replace user-specified values with missing values
-    x <- misty::as.na(x, na = as.na, check = check)
-
-    # Variable with missing values only
-    x.miss <- vapply(x, function(y) all(is.na(y)), FUN.VALUE = logical(1L))
-    if (isTRUE(any(x.miss))) {
-
-      stop(paste0("After converting user-missing values into NA, following variables are completely missing: ", paste(names(which(x.miss)), collapse = ", ")), call. = FALSE)
-
-    }
-
-  }
+  if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Numeric Variables ####
@@ -309,6 +362,12 @@ ci.prop <- function(x, method = c("wald", "wilson"), alternative = c("two.sided"
     # Check input 'digits'
     if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Please specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
+    # Check input 'write'
+    if (isTRUE(!is.null(write) && substr(write, nchar(write) - 3L, nchar(write)) != ".txt")) { stop("Please specify a character string with file extenstion '.txt' for the argument 'write'.") }
+
+    # Check input 'append'
+    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
+
     # Check input output
     if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
@@ -343,7 +402,7 @@ ci.prop <- function(x, method = c("wald", "wilson"), alternative = c("two.sided"
     n <- length(x)
 
     # Number of observations
-    if (isTRUE(n == 0L)) {
+    if (isTRUE(n <= 1L)) {
 
       ci <- c(NA, NA)
 
@@ -387,7 +446,7 @@ ci.prop <- function(x, method = c("wald", "wilson"), alternative = c("two.sided"
     }
 
     # Lower or upper limit
-    object <- switch(side, both = ci, low = ci[1], upp = ci[2])
+    object <- switch(side, both = ci, low = ci[1L], upp = ci[2L])
 
     return(object)
 
@@ -454,11 +513,35 @@ ci.prop <- function(x, method = c("wald", "wilson"), alternative = c("two.sided"
                  data = list(x = x, group = group, split = split),
                  args = list(alternative = alternative, conf.level = conf.level,
                              sort.var = sort.var, na.omit = na.omit, digits = digits,
-                             check = check, output = output),
+                             write = write, append = append, check = check, output = output),
                  result = result)
 
   class(object) <- "misty.object"
 
+
+
+  #_____________________________________________________________________________
+  #
+  # Write results --------------------------------------------------------------
+
+  if (isTRUE(!is.null(write))) {
+
+    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    ## Text file ####
+
+    # Send R output to textfile
+    sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
+
+    if (append && isTRUE(file.exists(write))) { write("", file = write, append = TRUE) }
+
+    # Print object
+    print(object, check = FALSE)
+
+    # Close file connection
+    sink()
+
+  }
+
   #_____________________________________________________________________________
   #
   # Output ---------------------------------------------------------------------
