@@ -4,56 +4,70 @@
 #' for one or more than one variable.
 #'
 #' By default, the function displays the absolute and percentage frequencies when
-#' specifying one variable in the argument \code{x}, while the function displays
+#' specifying one variable in the argument \code{...}, while the function displays
 #' only the absolute frequencies when more than one variable is specified. The
 #' function displays valid percentage frequencies only in the presence of missing
 #' values and excludes variables with all values missing from the analysis. Note
 #' that it is possible to mix numeric variables, factors, and character variables
-#' in the data frame specified in the argument \code{x}. By default, numeric
+#' in the data frame specified in the argument \code{...}. By default, numeric
 #' variables are rounded to three digits before computing the frequency table.
 #'
-#' @param x         a vector, factor, matrix or data frame.
-#' @param print     a character string indicating which percentage(s) to be
-#'                  printed on the console, i.e., no percentages (\code{"no"}),
-#'                  all percentages (\code{"all"}), percentage frequencies
-#'                  (\code{"print"}), and valid percentage frequencies
-#'                  (\code{"v.perc"}). Default setting when specifying one
-#'                  variable in \code{x} is \code{print = "all"}, while default
-#'                  setting when specifying more than one variable in \code{x}
-#'                  is \code{print = "no"} unless \code{split = TRUE}.
-#' @param freq      logical: if \code{TRUE} (default), absolute frequencies will
-#'                  be shown on the console.
-#' @param split     logical: if \code{TRUE}, output table is split by variables
-#'                  when specifying more than one variable in \code{x}.
-#' @param labels    logical: if \code{TRUE} (default), labels for the factor
-#'                  levels will be used.
-#' @param val.col   logical: if \code{TRUE}, values are shown in the columns,
-#'                  variables in the rows.
-#' @param round     an integer value indicating the number of decimal places
-#'                  to be used for rounding numeric variables.
-#' @param exclude   an integer value indicating the maximum number of unique
-#'                  values for variables to be included in the analysis when
-#'                  specifying more than one variable in \code{x} i.e.,
-#'                  variables with the number of unique values exceeding
-#'                  \code{exclude} will be excluded from the analysis. It is
-#'                  also possible to specify \code{exclude = FALSE} to include
-#'                  all variables in the analysis.
-#' @param digits    an integer value indicating the number of decimal places
-#'                  to be used for displaying percentages.
-#' @param as.na     a numeric vector indicating user-defined missing values,
-#'                  i.e. these values are converted to \code{NA} before
-#'                  conducting the analysis.
-#' @param write     a character string for writing the results into a Excel file
-#'                  naming a file with or without file extension '.xlsx', e.g.,
-#'                  \code{"Results.xlsx"} or \code{"Results"}.
-#' @param check     logical: if \code{TRUE}, argument specification is checked.
-#' @param output    logical: if \code{TRUE}, output is shown on the console.
+#' @param ...     a vector, factor, matrix or data frame. Alternatively, an
+#'                expression indicating the variable names in \code{data} e.g.,
+#'                \code{freq(x1, x2, x3, data = dat)}. Note that the operators
+#'                \code{.}, \code{+}, \code{-}, \code{~}, \code{:}, \code{::},
+#'                and \code{!} can also be used to select variables, see 'Details'
+#'                in the \code{\link{df.subset}} function.
+#' @param data    a data frame when specifying one or more variables in the
+#'                argument \code{...}. Note that the argument is \code{NULL}
+#'                when specifying a vector, factor, matrix or data frame for
+#'                the argument \code{...}.
+#' @param print   a character string indicating which percentage(s) to be printed
+#'                on the console, i.e., no percentages (\code{"no"}), all percentages
+#'                (\code{"all"}), percentage frequencies (\code{"print"}), and
+#'                valid percentage frequencies \code{"v.perc"}). Default setting
+#'                when specifying one variable in \code{...} is \code{print = "all"},
+#'                while default setting when specifying more than one variable
+#'                in \code{...} is \code{print = "no"} unless \code{split = TRUE}.
+#' @param freq    logical: if \code{TRUE} (default), absolute frequencies will
+#'                be shown on the console.
+#' @param split   logical: if \code{TRUE}, output table is split by variables
+#'                when specifying more than one variable in \code{...}.
+#' @param labels  logical: if \code{TRUE} (default), labels for the factor
+#'                levels will be used.
+#' @param val.col logical: if \code{TRUE}, values are shown in the columns,
+#'                variables in the rows.
+#' @param round   an integer value indicating the number of decimal places to be
+#'                used for rounding numeric variables.
+#' @param exclude an integer value indicating the maximum number of unique values
+#'                for variables to be included in the analysis when specifying
+#'                more than one variable in \code{...} i.e., variables with the
+#'                number of unique values exceeding \code{exclude} will be
+#'                excluded from the analysis. It is also possible to specify
+#'                \code{exclude = FALSE} to include all variables in the analysis.
+#' @param digits  an integer value indicating the number of decimal places to be
+#'                used for displaying percentages.
+#' @param as.na   a numeric vector indicating user-defined missing values, i.e.
+#'                these values are converted to \code{NA} before conducting the
+#'                analysis.
+#' @param write   a character string naming a file for writing the output into
+#'                either a text file with file extension \code{".txt"} (e.g.,
+#'                \code{"Output.txt"}) or Excel file with file extention
+#'                \code{".xlsx"}  (e.g., \code{"Output.xlsx"}). If the file
+#'                name does not contain any file extension, an Excel file will
+#'                be written.
+#' @param append  logical: if \code{TRUE} (default), output will be appended
+#'                to an existing text file with extension \code{.txt} specified
+#'                in \code{write}, if \code{FALSE} existing text file will be
+#'                overwritten.
+#' @param check   logical: if \code{TRUE} (default), argument specification is checked.
+#' @param output  logical: if \code{TRUE} (default), output is shown on the console.
 #'
 #' @author
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
 #' @seealso
-#' \code{\link{crosstab}}, \code{\link{descript}}, \code{\link{multilevel.descript}},
+#' \code{\link{crosstab}}, \code{\link{des cript}}, \code{\link{multilevel.descript}},
 #' \code{\link{na.descript}}, \code{\link{write.result}}
 #'
 #' @references
@@ -66,7 +80,7 @@
 #' \tabular{ll}{
 #' \code{call} \tab function call \cr
 #' \code{type} \tab type of analysis \cr
-#' \code{data} \tab matrix or data frame specified in \code{x} \cr
+#' \code{data} \tab data frame used for the current analysis \cr
 #' \code{args} \tab specification of function arguments \cr
 #' \code{result} \tab result table \cr
 #' }
@@ -74,81 +88,100 @@
 #' @export
 #'
 #' @examples
-#' dat <- data.frame(x1 = c(3, 3, 2, 3, 2, 3, 3, 2, 1, -99),
-#'                   x2 = c(2, 2, 1, 3, 1, 1, 3, 3, 2, 2),
-#'                   y1 = c(1, 4, NA, 5, 2, 4, 3, 5, NA, 1),
-#'                   y2 = c(2, 3, 4, 3, NA, 4, 2, 3, 4, 5),
-#'                   z = c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10))
+#' # Example 1a: Frequency table for 'cyl'
+#' freq(mtcars$cyl)
 #'
-#' # Frequency table for one variable
-#' freq(dat$x1)
+#' # Example 1b: Alternative specification using the 'data' argument
+#' freq(cyl, data = mtcars)
 #'
-#' # Frequency table for one variable,
-#' # values shown in columns
-#' freq(dat$x1, val.col = TRUE)
+#' # Example 2: Frequency table, values shown in columns
+#' freq(mtcars$cyl, val.col = TRUE)
 #'
-#' # Frequency table for one variable,
-#' # convert value -99 into NA
-#' freq(dat$x1, as.na = -99)
+#' # Example 3: Frequency table, use 3 digit for displaying percentages
+#' freq(mtcars$cyl, digits = 3)
 #'
-#' # Frequency table for one variable
-#' # use 3 digit for displaying percentages
-#' freq(dat$x1, digits = 3)
+#' # Example 4a: Frequency table for 'cyl', 'gear', and 'carb'
+#' freq(mtcars[, c("cyl", "gear", "carb")])
 #'
-#' # Frequency table for more than one variable
-#' freq(dat[, c("x1", "x2", "y1", "y2")])
+#' # Example 4b: Alternative specification using the 'data' argument
+#' freq(cyl, gear, carb, data = mtcars)
 #'
-#' # Frequency table for more than one variable,
-#' # values shown in columns
-#' freq(dat[, c("x1", "x2", "y1", "y2")], val.col = TRUE)
+#' # Example 5: Frequency table, with percentage frequencies
+#' freq(mtcars[, c("cyl", "gear", "carb")], print = "all")
 #'
-#' # Frequency table for more than one variable,
-#' # with percentage frequencies
-#' freq(dat[, c("x1", "x2", "y1", "y2")], print = "all")
+#' # Example 6: Frequency table, split output table
+#' freq(mtcars[, c("cyl", "gear", "carb")], split = TRUE)
 #'
-#' # Frequency table for more than one variable,
-#' # with percentage frequencies, values shown in columns
-#' freq(dat[, c("x1", "x2", "y1", "y2")], print = "all", val.col = TRUE)
-#'
-#' # Frequency table for more than one variable,
-#' # split output table
-#' freq(dat[, c("x1", "x2", "y1", "y2")], split = TRUE)
-#'
-#' # Frequency table for more than one variable,
-#' # exclude variables with more than 5 unique values
-#' freq(dat, exclude = 5)
-#'
-#' # Frequency table for a factor
-#' freq(factor(c("a", "a", "b", "c", "b")))
-#'
-#' # Frequency table for one variable,
-#' # do not use labels of the factor levels
-#' freq(factor(c("a", "a", "b", "c", "b")), labels = FALSE)
+#' # Example 7: Frequency table, exclude variables with more than 5 unique values
+#' freq(mtcars, exclude = 5)
 #'
 #' \dontrun{
-#' # Write Results into a Excel file
-#' freq(dat[, c("x1", "x2", "y1", "y2")], split = TRUE, write = "Frequencies.xlsx")
+#' # Example 8a: Write Results into a text file
+#' freq(mtcars[, c("cyl", "gear", "carb")], split = TRUE, write = "Frequencies.txt")
 #'
-#' result <- freq(dat[, c("x1", "x2", "y1", "y2")], split = TRUE, output = FALSE)
+#' # Example 8b: Write Results into a Excel file
+#' freq(mtcars[, c("cyl", "gear", "carb")], split = TRUE, write = "Frequencies.xlsx")
+#'
+#' result <- freq(mtcars[, c("cyl", "gear", "carb")], split = TRUE, output = FALSE)
 #' write.result(result, "Frequencies.xlsx")
 #' }
-freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
-                 split = FALSE, labels = TRUE, val.col = FALSE, round = 3,
-                 exclude = 15, digits = 2, as.na = NULL, write = NULL,
-                 check = TRUE, output = TRUE) {
+freq <- function(..., data = NULL, print = c("no", "all", "perc", "v.perc"),
+                 freq = TRUE, split = FALSE, labels = TRUE, val.col = FALSE,
+                 round = 3, exclude = 15, digits = 2, as.na = NULL, write = NULL,
+                 append = TRUE, check = TRUE, output = TRUE) {
 
   #_____________________________________________________________________________
   #
   # Initial Check --------------------------------------------------------------
 
-  # Check if input 'x' is missing
-  if (isTRUE(missing(x))) { stop("Please specify a vector, factor, matrix or data frame for the argument 'x'.", call. = FALSE) }
+  # Check if input '...' is missing
+  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
 
-  # Check if input 'x' is NULL
-  if (isTRUE(is.null(x))) { stop("Input specified for the argument 'x' is NULL.", call. = FALSE) }
+  # Check if input '...' is NULL
+  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+
+  # Check if input 'data' is data frame
+  if (isTRUE(!is.null(data) && !is.data.frame(data))) { stop("Please specify a data frame for the argument 'data'.", call. = FALSE) }
+
+  #_____________________________________________________________________________
+  #
+  # Initial Check --------------------------------------------------------------
+
+  # Check if input '...' is missing
+  if (isTRUE(missing(...))) { stop("Please specify the argument '...'.", call. = FALSE) }
+
+  # Check if input '...' is NULL
+  if (isTRUE(is.null(substitute(...)))) { stop("Input specified for the argument '...' is NULL.", call. = FALSE) }
+
+  # Check if input 'data' is data frame
+  if (isTRUE(!is.null(data) && !is.data.frame(data))) { stop("Please specify a data frame for the argument 'data'.", call. = FALSE) }
+
+  #_____________________________________________________________________________
+  #
+  # Data -----------------------------------------------------------------------
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data using the argument 'data' ####
+
+  if (isTRUE(!is.null(data))) {
+
+    # Variable names
+    var.names <- .var.names(..., data = data, check.chr = "a vector, factor, matrix or data frame")
+
+    # Extract data
+    x <- data[, var.names]
+
+  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+  ## Data without using the argument 'data' ####
+
+  } else {
+
+    # Extract data
+    x <- eval(..., enclos = parent.frame())
+
+  }
 
   # Check if input 'x' is not a list or an array
-
   if (isTRUE((is.list(x) && !is.data.frame(x)) || (is.array(x) && !is.matrix(x)))) { stop("Please specify a vector, factor, matrix or data frame for the argument 'x'.", call. = FALSE) }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -159,37 +192,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Convert user-missing values into NA ####
 
-  if (isTRUE(!is.null(as.na))) {
-
-    #......
-    # Check input 'as.na'
-    if (isTRUE(check)) {
-
-      # Factor or Vector
-      if (isTRUE(is.atomic(x) || is.factor(x))) {
-
-        na.x <- !as.na %in% x
-
-      # Matrix or data frame
-      } else if (isTRUE(is.matrix(x) || is.data.frame(x))) {
-
-        na.x <- vapply(as.character(as.na), function(y) !y %in% misty::chr.trim(apply(as.matrix(x), 2L, as.character)), FUN.VALUE = logical(1L))
-
-      }
-
-      if (isTRUE(any(na.x))) {
-
-        warning(paste0(ifelse(sum(na.x) == 1L, "Value ", "Values "), "specified in the argument 'as.na' ",
-                       ifelse(sum(na.x) == 1L, "was ", "were "), "not found in 'x': ",
-                       paste(as.na[na.x], collapse = ", ")), call. = FALSE)
-
-      }
-
-    }
-
-    x <- misty::as.na(x, na = as.na, check = FALSE)
-
-  }
+  if (isTRUE(!is.null(as.na))) { x <- .as.na(x, na = as.na) }
 
   #_____________________________________________________________________________
   #
@@ -270,6 +273,9 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
     # Check input 'digits'
     if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
+    # Check input 'append'
+    if (isTRUE(!is.logical(append))) { stop("Please specify TRUE or FALSE for the argument 'append'.", call. = FALSE) }
+
     # Check input 'output'
     if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
@@ -332,8 +338,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
 
       if (isTRUE(any(apply(combn(length(x[, x.factor]), 2L), 2L, function(y) !identical(factor.unique[[y[1L]]], factor.unique[[y[2L]]]))))) {
 
-        warning("Variable do not have the same factor levels, i.e., values may not be comparable across variables.",
-                call. = FALSE)
+        warning("Variable do not have the same factor levels, i.e., values may not be comparable across variables.", call. = FALSE)
 
       }
 
@@ -353,7 +358,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
                      function(y) any(na.omit(nchar(gsub("(.*)(\\.)|([0]*$)","", y)) > round)), FUN.VALUE = logical(1L))))
 
   # If at least one numeric variable
-  if (isTRUE(length(x.numeric) > 0)) {
+  if (isTRUE(length(x.numeric) > 0L)) {
 
     x[, x.numeric] <- lapply(x[, x.numeric, drop = FALSE], base::round, digits = round)
 
@@ -388,8 +393,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
 
           }
 
-          warning(paste0("Variables with more than ", exclude, " unique values were excluded: ", paste(names(x.exclude), collapse = ", ")),
-                  call. = FALSE)
+          warning(paste0("Variables with more than ", exclude, " unique values were excluded: ", paste(names(x.exclude), collapse = ", ")), call. = FALSE)
 
         }
 
@@ -438,8 +442,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
     ### Values in rows ####
     } else {
 
-      freqtab <- data.frame(matrix(c(x.abs, x.perc, x.v.perc, NA), nrow = 3L,
-                                   dimnames = list(c ("Freq", "Perc", "V.Perc"), names(x.abs)), byrow = TRUE),
+      freqtab <- data.frame(matrix(c(x.abs, x.perc, x.v.perc, NA), nrow = 3L, dimnames = list(c ("Freq", "Perc", "V.Perc"), names(x.abs)), byrow = TRUE),
                             stringsAsFactors = FALSE, check.names = FALSE)
 
     }
@@ -485,31 +488,21 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
       }
 
       # Character
-      if (isTRUE(any(vapply(x, is.character, FUN.VALUE = logical(1L))))) {
-
-        x.levels <- c(x.levels, na.omit(sort(unique(unlist(x[, vapply(x, is.character, FUN.VALUE = logical(1L))])))))
-
-      }
+      if (isTRUE(any(vapply(x, is.character, FUN.VALUE = logical(1L))))) { x.levels <- c(x.levels, na.omit(sort(unique(unlist(x[, vapply(x, is.character, FUN.VALUE = logical(1L))]))))) }
 
       # Logical
-      if (isTRUE(any(vapply(x, is.logical, FUN.VALUE = logical(1))))) {
-
-        x.levels <- c(x.levels, c(TRUE, FALSE))
-
-      }
+      if (isTRUE(any(vapply(x, is.logical, FUN.VALUE = logical(1L))))) { x.levels <- c(x.levels, c(TRUE, FALSE)) }
 
       x.levels <- unique(x.levels)
 
       # Absolute frequencies
-      x.abs <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "always"),
-                      FUN.VALUE = integer(length(x.levels) + 1L))
+      x.abs <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "always"), FUN.VALUE = integer(length(x.levels) + 1L))
 
       # Percentages
       x.perc <- apply(x.abs, 2, function(y) ifelse(y != 0L, prop.table(y) * 100L, 0L))
 
       # Valid Percentages
-      x.v.perc <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "no"),
-                         FUN.VALUE = integer(length(x.levels)))
+      x.v.perc <- vapply(x, function(y) table(factor(y, levels = x.levels), useNA = "no"), FUN.VALUE = integer(length(x.levels)))
 
       # More than one value
       if (isTRUE(is.matrix(x.v.perc))) {
@@ -519,8 +512,7 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
       # One value
       } else {
 
-        x.v.perc <- matrix(prop.table(x.v.perc) * 100L, nrow = 1,
-                           dimnames = list(na.omit(row.names(x.abs)), names(x.v.perc)))
+        x.v.perc <- matrix(prop.table(x.v.perc) * 100L, nrow = 1, dimnames = list(na.omit(row.names(x.abs)), names(x.v.perc)))
 
       }
 
@@ -528,16 +520,13 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
       if (!isTRUE(val.col)) {
 
         # Absolute frequencies table
-        abs.freqtab <- data.frame(Value = rownames(x.abs), x.abs,
-                                  stringsAsFactors = FALSE, row.names = NULL)
+        abs.freqtab <- data.frame(Value = rownames(x.abs), x.abs, stringsAsFactors = FALSE, row.names = NULL)
 
         # Percentages table
-        perc.freqtab <- data.frame(Value = rownames(x.perc), x.perc,
-                                   stringsAsFactors = FALSE, row.names = NULL)
+        perc.freqtab <- data.frame(Value = rownames(x.perc), x.perc, stringsAsFactors = FALSE, row.names = NULL)
 
         # Valid Percentages table
-        v.perc.freqtab <- data.frame(Value = rownames(x.v.perc), x.v.perc,
-                                     stringsAsFactors = FALSE, row.names = NULL)
+        v.perc.freqtab <- data.frame(Value = rownames(x.v.perc), x.v.perc, stringsAsFactors = FALSE, row.names = NULL)
 
         # Convert 'Value' in numeric
         if(all(grepl("(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))$)|(^(-|\\+)?((\\.?\\d+)|(\\d+\\.\\d+)|(\\d+\\.?))e(-|\\+)?(\\d+)$)",
@@ -553,18 +542,15 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
       } else {
 
         # Absolute frequencies table
-        abs.freqtab <- data.frame(Var = colnames(x.abs), matrix(t(x.abs), nrow = ncol(x.abs),
-                                                                dimnames = list(NULL, rownames(x.abs))),
+        abs.freqtab <- data.frame(Var = colnames(x.abs), matrix(t(x.abs), nrow = ncol(x.abs), dimnames = list(NULL, rownames(x.abs))),
                                   check.names = FALSE, stringsAsFactors = FALSE)
 
         # Percentages table
-        perc.freqtab <- data.frame(Var = colnames(x.perc), matrix(t(x.perc), nrow = ncol(x.perc),
-                                                                  dimnames = list(NULL, rownames(x.perc))),
+        perc.freqtab <- data.frame(Var = colnames(x.perc), matrix(t(x.perc), nrow = ncol(x.perc), dimnames = list(NULL, rownames(x.perc))),
                                    check.names = FALSE, stringsAsFactors = FALSE)
 
         # Valid Percentages table
-        v.perc.freqtab <- data.frame(Var = colnames(x.v.perc), matrix(t(x.v.perc), nrow = ncol(x.v.perc),
-                                                                      dimnames = list(NULL, rownames(x.v.perc))),
+        v.perc.freqtab <- data.frame(Var = colnames(x.v.perc), matrix(t(x.v.perc), nrow = ncol(x.v.perc), dimnames = list(NULL, rownames(x.v.perc))),
                                      check.names = FALSE, stringsAsFactors = FALSE)
 
       }
@@ -590,7 +576,8 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
                  data = x,
                  args = list(print = print, freq = freq, split = split, labels = labels,
                              val.col = val.col, round = round, digits = digits,
-                             as.na = as.na, check = check, output = output),
+                             as.na = as.na, write = write, append = append,
+                             check = check, output = output),
                  result = freqtab)
 
   class(object) <- "misty.object"
@@ -605,7 +592,35 @@ freq <- function(x, print = c("no", "all", "perc", "v.perc"), freq = TRUE,
   #
   # Output ---------------------------------------------------------------------
 
-  if (isTRUE(output)) { print(object, check = FALSE) }
+
+  if (isTRUE(!is.null(write))) {
+
+    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    ## Text file ####
+
+    if (isTRUE(grepl("\\.txt", write))) {
+
+      # Send R output to textfile
+      sink(file = write, append = ifelse(isTRUE(file.exists(write)), append, FALSE), type = "output", split = FALSE)
+
+      if (append && isTRUE(file.exists(write))) { write("", file = write, append = TRUE) }
+
+      # Print object
+      print(object, check = FALSE)
+
+      # Close file connection
+      sink()
+
+      #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+      ## Excel file ####
+
+    } else {
+
+      misty::write.result(object, file = write)
+
+    }
+
+  }
 
   #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   ## Message ####
